@@ -19,10 +19,7 @@ DIMAP V2 super class.
 See `here <www.engesat.com.br/wp-content/uploads/PleiadesUserGuide-17062019.pdf>`_
 for more information.
 """
-import glob
 import logging
-import math
-import os
 import time
 from abc import abstractmethod
 from datetime import date, datetime
@@ -34,26 +31,20 @@ import affine
 import geopandas as gpd
 import numpy as np
 import rasterio
-from cloudpathlib import AnyPath, CloudPath
+from cloudpathlib import CloudPath
 from lxml import etree
 from rasterio import crs as riocrs
-from rasterio import features, rpc, transform, warp
-from rasterio.crs import CRS
-from rasterio.enums import Resampling
-from sertit import files, rasters, rasters_rio, vectors
+from rasterio import features, transform
+from sertit import files, rasters_rio, vectors
 from sertit.misc import ListEnum
 from sertit.rasters import XDS_TYPE
-from sertit.snap import MAX_CORES
-from sertit.vectors import WGS84
-from shapely.geometry import box
 
-from eoreader import utils
+from eoreader import cache, cached_property, utils
 from eoreader.bands.alias import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS
 from eoreader.bands.bands import BandNames
 from eoreader.bands.bands import OpticalBandNames as obn
-from eoreader.env_vars import DEM_PATH
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
-from eoreader.products.optical.optical_product import OpticalProduct
+from eoreader.products.optical.vhr_product import VhrProduct
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
@@ -158,7 +149,7 @@ class DimapBandCombination(ListEnum):
     """
 
 
-class DimapProduct(OpticalProduct):
+class DimapProduct(VhrProduct):
     """
     Super Class of DIMAP V2 products.
     See `here <www.engesat.com.br/wp-content/uploads/PleiadesUserGuide-17062019.pdf>`_
@@ -183,13 +174,21 @@ class DimapProduct(OpticalProduct):
         # Initialization from the super class
         super().__init__(product_path, archive_path, output_path, remove_tmp)
 
+    def _pre_init(self) -> None:
+        """
+        Function used to pre_init the products
+        (setting needs_extraction and so on)
+        """
+        self.needs_extraction = False
+
+        # Post init done by the super class
+        super()._pre_init()
+
     def _post_init(self) -> None:
         """
         Function used to post_init the products
         (setting sensor type, band names and so on)
         """
-        self.needs_extraction = False
-
         # Band combination
         root, _ = self.read_mtd()
         band_combi = root.findtext(".//SPECTRAL_PROCESSING")
@@ -216,7 +215,7 @@ class DimapProduct(OpticalProduct):
         prod_type = root.find(".//DATASET_QL_PATH").attrib["href"].split("_")[4]
         if not prod_type:
             raise InvalidProductError(
-                "Cannot find the product type (from PROCESSING_LEVEL) type in the metadata file"
+                "Cannot find DATASET_QL_PATH in the metadata file"
             )
         self.product_type = getattr(DimapProductType, prod_type)
 
@@ -225,17 +224,41 @@ class DimapProduct(OpticalProduct):
             self.band_names.map_bands({obn.PAN: 1})
         elif self.band_combi in [DimapBandCombination.MS, DimapBandCombination.PMS]:
             self.band_names.map_bands(
-                {obn.BLUE: 3, obn.GREEN: 2, obn.RED: 1, obn.NIR: 4}
+                {obn.BLUE: 3, obn.GREEN: 2, obn.RED: 1, obn.NIR: 4, obn.NARROW_NIR: 4}
             )
         elif self.band_combi in [DimapBandCombination.MS_N, DimapBandCombination.PMS_N]:
             self.band_names.map_bands({obn.BLUE: 3, obn.GREEN: 2, obn.RED: 1})
         elif self.band_combi in [DimapBandCombination.MS_X, DimapBandCombination.PMS_X]:
-            self.band_names.map_bands({obn.GREEN: 1, obn.RED: 2, obn.NIR: 3})
+            self.band_names.map_bands(
+                {obn.GREEN: 1, obn.RED: 2, obn.NIR: 3, obn.NARROW_NIR: 3}
+            )
         else:
             raise InvalidProductError(
                 f"Unusual band combination: {self.band_combi.name}"
             )
 
+    def _get_raw_crs(self) -> riocrs.CRS:
+        """
+        Get raw CRS of the tile
+
+        Returns:
+            rasterio.crs.CRS: CRS object
+        """
+        # Open metadata
+        root, _ = self.read_mtd()
+
+        # Get CRS
+        crs_name = root.findtext(".//GEODETIC_CRS_NAME")
+        if not crs_name:
+            crs_name = root.findtext(".//PROJECTED_CRS_CODE")
+            if not crs_name:
+                raise InvalidProductError(
+                    "Cannot find the CRS name (from GEODETIC_CRS_NAME or PROJECTED_CRS_CODE) type in the metadata file"
+                )
+
+        return riocrs.CRS.from_string(crs_name)
+
+    @cached_property
     def crs(self) -> riocrs.CRS:
         """
         Get UTM projection of the tile
@@ -245,7 +268,7 @@ class DimapProduct(OpticalProduct):
             >>> from eoreader.reader import Reader
             >>> path = r"IMG_PHR1B_PMS_001"
             >>> prod = Reader().open(path)
-            >>> prod.crs()
+            >>> prod.crs
             CRS.from_epsg(32618)
 
         Returns:
@@ -267,30 +290,7 @@ class DimapProduct(OpticalProduct):
 
         return utm
 
-    def get_default_band_path(self) -> Union[CloudPath, Path]:
-        """
-        Get default band (`GREEN` for optical data) path.
-
-        .. WARNING:
-            If you are using a non orthorectified product, this function will orthorectify the stack.
-            To do so, you **MUST** provide a DEM trough the EOREADER_DEM_PATH environment variable
-
-        .. WARNING:
-            If you are using a non projected product, this function will reproject the stack.
-
-        .. code-block:: python
-
-            >>> from eoreader.reader import Reader
-            >>> path = r"IMG_PHR1B_PMS_001"
-            >>> prod = Reader().open(path)
-            >>> prod.get_default_band_path()
-            'IMG_PHR1A_PMS_001/DIM_PHR1A_PMS_202005110231585_ORT_5547047101.XML'
-
-        Returns:
-            Union[CloudPath, Path]: Default band path
-        """
-        return self._get_default_utm_band(self.resolution)
-
+    @cached_property
     def footprint(self) -> gpd.GeoDataFrame:
         """
         Get real footprint in UTM of the products (without nodata, in french == emprise utile)
@@ -300,7 +300,7 @@ class DimapProduct(OpticalProduct):
             >>> from eoreader.reader import Reader
             >>> path = r"IMG_PHR1B_PMS_001"
             >>> prod = Reader().open(path)
-            >>> prod.footprint()
+            >>> prod.footprint
                                                          gml_id  ...                                           geometry
             0  source_image_footprint-DS_PHR1A_20200511023124...  ...  POLYGON ((707025.261 9688613.833, 707043.276 9...
             [1 rows x 3 columns]
@@ -308,27 +308,7 @@ class DimapProduct(OpticalProduct):
         Returns:
             gpd.GeoDataFrame: Footprint as a GeoDataFrame
         """
-        return self.open_mask("ROI").to_crs(self.crs())
-
-    def extent(self) -> gpd.GeoDataFrame:
-        """
-        Get UTM extent of the tile
-
-        .. code-block:: python
-
-            >>> from eoreader.reader import Reader
-            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-            >>> prod = Reader().open(path)
-            >>> prod.utm_extent()
-                                                        geometry
-            0  POLYGON ((309780.000 4390200.000, 309780.000 4...
-
-        Returns:
-            gpd.GeoDataFrame: Footprint in UTM
-        """
-        def_tr, def_w, def_h, def_crs = self.default_transform()
-        bounds = transform.array_bounds(def_h, def_w, def_tr)
-        return gpd.GeoDataFrame(geometry=[box(*bounds)], crs=def_crs)
+        return self.open_mask("ROI").to_crs(self.crs)
 
     def get_datetime(self, as_datetime: bool = False) -> Union[str, datetime]:
         """
@@ -350,268 +330,71 @@ class DimapProduct(OpticalProduct):
         Returns:
              Union[str, datetime.datetime]: Its acquisition datetime
         """
-        # Get MTD XML file
-        root, _ = self.read_mtd()
-        date_str = root.findtext(".//IMAGING_DATE")
-        time_str = root.findtext(".//IMAGING_TIME")
-        if not date_str or not time_str:
-            raise InvalidProductError(
-                "Cannot find the product imaging date and time in the metadata file."
+        if self.datetime is None:
+            # Get MTD XML file
+            root, _ = self.read_mtd()
+            date_str = root.findtext(".//IMAGING_DATE")
+            time_str = root.findtext(".//IMAGING_TIME")
+            if not date_str or not time_str:
+                raise InvalidProductError(
+                    "Cannot find the product imaging date and time in the metadata file."
+                )
+
+            # Convert to datetime
+            date_dt = date.fromisoformat(date_str)
+            try:
+                time_dt = time.strptime(time_str, "%H:%M:%S.%fZ")
+            except ValueError:
+                time_dt = time.strptime(
+                    time_str, "%H:%M:%S.%f"
+                )  # Sometimes without a Z
+
+            date_str = (
+                f"{date_dt.strftime('%Y%m%d')}T{time.strftime('%H%M%S', time_dt)}"
             )
 
-        # Convert to datetime
-        date_dt = date.fromisoformat(date_str)
-        try:
-            time_dt = time.strptime(time_str, "%H:%M:%S.%fZ")
-        except ValueError:
-            time_dt = time.strptime(time_str, "%H:%M:%S.%f")  # Sometimes without a Z
+            if as_datetime:
+                date_str = datetime.strptime(date_str, DATETIME_FMT)
 
-        date_str = f"{date_dt.strftime('%Y%m%d')}T{time.strftime('%H%M%S', time_dt)}"
-
-        if as_datetime:
-            date_str = datetime.strptime(date_str, DATETIME_FMT)
+        else:
+            date_str = self.datetime
+            if not as_datetime:
+                date_str = date_str.strftime(DATETIME_FMT)
 
         return date_str
 
-    def get_band_paths(self, band_list: list, resolution: float = None) -> dict:
+    def _get_ortho_path(self) -> Union[CloudPath, Path]:
         """
-        Return the paths of required bands.
-
-        .. code-block:: python
-
-            >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
-            >>> path = r"IMG_PHR1B_PMS_001"
-            >>> prod = Reader().open(path)
-            >>> prod.get_band_paths([GREEN, RED])
-            {
-                <OpticalBandNames.GREEN: 'GREEN'>:
-                'IMG_PHR1A_PMS_001/DIM_PHR1A_PMS_202005110231585_ORT_5547047101.XML',
-                <OpticalBandNames.RED: 'RED'>:
-                'IMG_PHR1A_PMS_001/DIM_PHR1A_PMS_202005110231585_ORT_5547047101.XML'
-            }
-
-        Args:
-            band_list (list): List of the wanted bands
-            resolution (float): Band resolution
+        Get the orthorectified path of the bands.
 
         Returns:
-            dict: Dictionary containing the path of each queried band
+            Union[CloudPath, Path]: Orthorectified path
         """
-        ortho_path = self._get_band_folder().joinpath(
-            f"{self.condensed_name}_ortho.tif"
-        )
-        if not self.ortho_path:
-            if self.product_type in [DimapProductType.SEN, DimapProductType.PRJ]:
-                self.ortho_path = ortho_path
-                if not self.ortho_path.is_file():
-                    LOGGER.info(
-                        f"Manually orthorectified stack not given by the user. "
-                        f"Reprojecting data here: {self.ortho_path} "
-                        "(May be inaccurate on steep terrain, depending on the DEM resolution.)"
-                    )
-
-                    # Reproject and write on disk data
-                    with rasterio.open(str(self._get_dimap_path())) as src:
-                        out_arr, meta = self._reproject(src.read(), src.meta, src.rpcs)
-                        rasters_rio.write(out_arr, meta, self.ortho_path)
-
-            else:
-                self.ortho_path = self._get_dimap_path()
-
-        # Processed path names
-        band_paths = {}
-        for band in band_list:
-            # Get clean band path
-            clean_band = self._get_clean_band_path(band, resolution=resolution)
-            if clean_band.is_file():
-                band_paths[band] = clean_band
-            else:
-                # First look for reprojected bands
-                reproj_path = self._create_utm_band_path(
-                    band=band.name, resolution=resolution
+        if self.product_type in [DimapProductType.SEN, DimapProductType.PRJ]:
+            ortho_name = f"{self.condensed_name}_ortho.tif"
+            ortho_path = self._get_band_folder().joinpath(ortho_name)
+            if not ortho_path.is_file():
+                ortho_path = self._get_band_folder(writable=True).joinpath(ortho_name)
+                LOGGER.info(
+                    f"Manually orthorectified stack not given by the user. "
+                    f"Reprojecting data here: {ortho_path} "
+                    "(May be inaccurate on steep terrain, depending on the DEM resolution.)"
                 )
-                if not reproj_path.is_file():
-                    # Then for original data
-                    path = self.ortho_path
-                else:
-                    path = reproj_path
 
-                band_paths[band] = path
+                # Reproject and write on disk data
+                with rasterio.open(str(self._get_dimap_path())) as src:
+                    out_arr, meta = self._reproject(src.read(), src.meta, src.rpcs)
+                    rasters_rio.write(out_arr, meta, ortho_path)
 
-        return band_paths
-
-    def _reproject(
-        self, src_arr: np.ndarray, src_meta: dict, rpcs: rpc.RPC
-    ) -> (np.ndarray, dict):
-        """
-        Reproject using RPCs
-
-        Args:
-            src_arr (np.ndarray): Array to reproject
-            src_meta (dict): Metadata
-            rpcs (rpc.RPC): RPCs
-
-        Returns:
-            (np.ndarray, dict): Reprojected array and its metadata
-        """
-        # Get DEM path
-        dem_path = os.environ.get(DEM_PATH)
-        if not dem_path:
-            raise ValueError(
-                f"You are using a non orthorectified Pleiades product {self.path}, "
-                f"you must provide a valid DEM through the {DEM_PATH} environment variable"
-            )
         else:
-            dem_path = AnyPath(dem_path)
-            if isinstance(dem_path, CloudPath):
-                raise TypeError(
-                    "gdalwarp cannot process DEM stored on cloud with 'RPC_DEM' argument, "
-                    "hence cloud-stored DEM cannot be used with non orthorectified DIMAP data."
-                    f"(DEM: {dem_path}, DIMAP data: {self.name})"
-                )
+            ortho_path = self._get_dimap_path()
 
-        # Set RPC keywords
-        kwargs = {"RPC_DEM": dem_path, "RPC_DEM_MISSING_VALUE": 0}
-        # TODO:  add "refine_gcps" ? With which tolerance ? (ie. '-refine_gcps 500 1.9')
-        #  (https://gdal.org/programs/gdalwarp.html#cmdoption-gdalwarp-refine_gcps)
-
-        # Reproject
-        # WARNING: may not give correct output resolution
-        out_arr, dst_transform = warp.reproject(
-            src_arr,
-            rpcs=rpcs,
-            src_crs=WGS84,
-            dst_crs=self.crs(),
-            resolution=self.resolution,
-            src_nodata=0,
-            dst_nodata=0,  # input data should be in integer
-            num_threads=MAX_CORES,
-            resampling=Resampling.bilinear,
-            **kwargs,
-        )
-        # Get dims
-        count, height, width = out_arr.shape
-
-        # Update metadata
-        meta = src_meta.copy()
-        meta["transform"] = dst_transform
-        meta["driver"] = "GTiff"
-        meta["compress"] = "lzw"
-        meta["nodata"] = 0
-        meta["crs"] = self.crs()
-        meta["width"] = width
-        meta["height"] = height
-        meta["count"] = count
-
-        # Just in case, read the array with the most appropriate resolution
-        # as the warping sometimes gives not the closest resolution possible to the wanted one
-        if not math.isclose(dst_transform.a, self.resolution, rel_tol=1e-4):
-            out_arr, meta = rasters_rio.read(
-                (out_arr, meta), resolution=self.resolution
-            )
-
-        return out_arr, meta
-
-    def _read_band(
-        self,
-        path: Union[CloudPath, Path],
-        band: BandNames = None,
-        resolution: Union[tuple, list, float] = None,
-        size: Union[list, tuple] = None,
-    ) -> XDS_TYPE:
-        """
-        Read band from disk.
-
-        .. WARNING::
-            Invalid pixels are not managed here
-
-        Args:
-            path (Union[CloudPath, Path]): Band path
-            band (BandNames): Band to read
-            resolution (Union[tuple, list, float]): Resolution of the wanted band, in dataset resolution unit (X, Y)
-            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
-        Returns:
-            XDS_TYPE: Band xarray
-        """
-        with rasterio.open(str(path)) as dst:
-            dst_crs = dst.crs
-
-            # Compute resolution from size (if needed)
-            if resolution is None and size is not None:
-                resolution = self._resolution_from_size(size)
-
-            # Reproj path in case
-            reproj_path = self._create_utm_band_path(
-                band=band.name, resolution=resolution
-            )
-
-            # Manage the case if we got a LAT LON product
-            if not dst_crs.is_projected:
-                if not reproj_path.is_file():
-                    # Warp band if needed
-                    self._warp_band(
-                        path,
-                        band,
-                        reproj_path=reproj_path,
-                        resolution=resolution,
-                    )
-
-                # Read band
-                band_xda = utils.read(
-                    reproj_path,
-                    resolution=resolution,
-                    size=size,
-                    resampling=Resampling.bilinear,
-                )
-
-            # Manage the case if we open a simple band (EOReader processed bands)
-            elif dst.count == 1:
-                # Read band
-                band_xda = utils.read(
-                    path,
-                    resolution=resolution,
-                    size=size,
-                    resampling=Resampling.bilinear,
-                )
-
-            # Manage the case if we open a stack (native DIMAP bands)
-            else:
-                # Read band
-                band_xda = utils.read(
-                    path,
-                    resolution=resolution,
-                    size=size,
-                    resampling=Resampling.bilinear,
-                    indexes=[self.band_names[band]],
-                )
-
-            # If nodata not set, set it here
-            if not band_xda.rio.encoded_nodata:
-                band_xda = rasters.set_nodata(band_xda, 0)
-
-            # Compute the correct radiometry of the band
-            if dst.meta["dtype"] == "uint16":
-                band_xda /= 10000.0
-
-            # Pop useless long name
-            if "long_name" in band_xda.attrs:
-                band_xda.attrs.pop("long_name")
-
-            # To float32
-            if band_xda.dtype != np.float32:
-                band_xda = band_xda.astype(np.float32)
-
-        return band_xda
+        return ortho_path
 
     # pylint: disable=R0913
     # R0913: Too many arguments (6/5) (too-many-arguments)
     def _manage_invalid_pixels(
-        self,
-        band_arr: XDS_TYPE,
-        band: obn,
-        resolution: float = None,
-        size: Union[list, tuple] = None,
+        self, band_arr: XDS_TYPE, band: obn, **kwargs
     ) -> XDS_TYPE:
         """
         Manage invalid pixels (Nodata, saturated, defective...)
@@ -622,8 +405,7 @@ class DimapProduct(OpticalProduct):
         Args:
             band_arr (XDS_TYPE): Band array
             band (obn): Band name as an OpticalBandNames
-            resolution (float): Band resolution in meters
-            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
+            kwargs: Other arguments used to load bands
 
         Returns:
             XDS_TYPE: Cleaned band array
@@ -661,33 +443,6 @@ class DimapProduct(OpticalProduct):
 
         return self._set_nodata_mask(band_arr, nodata)
 
-    def _load_bands(
-        self, bands: list, resolution: float = None, size: Union[list, tuple] = None
-    ) -> dict:
-        """
-        Load bands as numpy arrays with the same resolution (and same metadata).
-
-        Args:
-            bands list: List of the wanted bands
-            resolution (float): Band resolution in meters
-            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
-        Returns:
-            dict: Dictionary {band_name, band_xarray}
-        """
-        # Return empty if no band are specified
-        if not bands:
-            return {}
-
-        # Get band paths
-        if resolution is None and size is not None:
-            resolution = self._resolution_from_size(size)
-        band_paths = self.get_band_paths(bands, resolution=resolution)
-
-        # Open bands and get array (resampled if needed)
-        band_arrays = self._open_bands(band_paths, resolution=resolution, size=size)
-
-        return band_arrays
-
     def _get_condensed_name(self) -> str:
         """
         Get PlanetScope products condensed name ({date}_PLD_{product_type}_{band_combi}).
@@ -697,6 +452,7 @@ class DimapProduct(OpticalProduct):
         """
         return f"{self.get_datetime()}_{self.platform.name}_{self.product_type.name}_{self.band_combi.name}"
 
+    @cache
     def get_mean_sun_angles(self) -> (float, float):
         """
         Get Mean Sun angles (Azimuth and Zenith angles)
@@ -734,6 +490,7 @@ class DimapProduct(OpticalProduct):
 
         return azimuth_angle, zenith_angle
 
+    @cache
     def _read_mtd(self) -> (etree._Element, dict):
         """
         Read metadata and outputs the metadata XML root and its namespaces as a dict
@@ -757,7 +514,11 @@ class DimapProduct(OpticalProduct):
         return has_band
 
     def _load_clouds(
-        self, bands: list, resolution: float = None, size: Union[list, tuple] = None
+        self,
+        bands: list,
+        resolution: float = None,
+        size: Union[list, tuple] = None,
+        **kwargs,
     ) -> dict:
         """
         Load cloud files as xarrays.
@@ -768,6 +529,7 @@ class DimapProduct(OpticalProduct):
             bands (list): List of the wanted bands
             resolution (int): Band resolution in meters
             size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
+            kwargs: Additional arguments
         Returns:
             dict: Dictionary {band_name, band_xarray}
         """
@@ -864,11 +626,10 @@ class DimapProduct(OpticalProduct):
         mandatory_masks = ["CLD", "DET", "QTE", "ROI", "SLT", "SNW"]
         optional_masks = ["VIS"]
         assert mask_str in mandatory_masks + optional_masks
-        crs = self.crs()
+        crs = self.crs
 
-        mask_path = self._get_band_folder().joinpath(
-            f"{self.condensed_name}_MSK_{mask_str}.geojson"
-        )
+        mask_name = f"{self.condensed_name}_MSK_{mask_str}.geojson"
+        mask_path = self._get_band_folder().joinpath(mask_name)
         if mask_path.is_file():
             mask = vectors.read(mask_path)
         elif mask_str in self._empty_mask:
@@ -948,18 +709,17 @@ class DimapProduct(OpticalProduct):
                     DimapProductType.MOS,
                 ]
             ):
-                with rasterio.open(str(self._get_dimap_path())) as dim_dst:
-                    mask.crs = dim_dst.crs
-
                 # Convert to target CRS
-                mask = mask.to_crs(self.crs())
+                mask.crs = self._get_raw_crs()
+                mask = mask.to_crs(self.crs)
 
             # Save to file
             if mask.empty:
                 # Empty mask cannot be written on file
                 self._empty_mask.append(mask_str)
             else:
-                mask.to_file(mask_path, driver="GeoJSON")
+                mask_path = self._get_band_folder(writable=True).joinpath(mask_name)
+                mask.to_file(str(mask_path), driver="GeoJSON")
 
         return mask
 
@@ -993,35 +753,6 @@ class DimapProduct(OpticalProduct):
             dtype=np.uint8,
         )
 
-    def _get_path(self, filename: str, extension: str) -> Union[CloudPath, Path]:
-        """
-        Get either the archived path of the normal path of an asset
-
-        Args:
-            filename (str): Filename with wildcards
-            extension (str): Extension
-
-        Returns:
-            Union[list, CloudPath, Path]: Path or list of paths (needs this because of potential mosaic)
-
-        """
-        path = []
-        try:
-            if self.is_archived:
-                path = files.get_archived_rio_path(
-                    self.path,
-                    f".*{filename}.*\.{extension}",
-                )
-            else:
-                path = next(self.path.glob(f"*{filename}*.{extension}"))
-
-        except (FileNotFoundError, IndexError):
-            LOGGER.warning(
-                f"No file corresponding to *{filename}*.{extension} found in {self.path}"
-            )
-
-        return path
-
     def _get_dimap_path(self) -> Union[CloudPath, Path]:
         """
         Get the DIMAP filepath
@@ -1031,165 +762,3 @@ class DimapProduct(OpticalProduct):
 
         """
         return self._get_path("DIM_", "XML")
-
-    def _create_utm_band_path(
-        self, band: str, resolution: Union[float, tuple, list] = None
-    ) -> Union[CloudPath, Path]:
-        """
-        Create the UTM band path
-
-        Args:
-            band (str): Band in string as written on the filepath
-            resolution (Union[float, tuple, list]): Resolution of the wanted UTM band
-
-        Returns:
-            Union[CloudPath, Path]: UTM band path
-        """
-        if resolution:
-            try:
-                resolution = str(resolution).replace(".", "-")
-            except TypeError:
-                pass
-            res_str = f"_{str(resolution).replace('.', '-')}m"
-        else:
-            res_str = ""
-
-        return self._get_band_folder().joinpath(
-            f"{self.condensed_name}_{band}{res_str}.tif"
-        )
-
-    def _warp_band(
-        self,
-        path: Union[str, CloudPath, Path],
-        band: BandNames,
-        reproj_path: Union[str, CloudPath, Path],
-        resolution: float = None,
-    ) -> None:
-        """
-        Warp band to UTM
-
-        Args:
-            path (Union[str, CloudPath, Path]): Band path to warp
-            band (band): Band to warp
-            reproj_path (Union[str, CloudPath, Path]): Path where to write the reprojected band
-            resolution (int): Band resolution in meters
-
-        """
-        if not resolution:
-            resolution = self.resolution
-
-        LOGGER.info(
-            f"Reprojecting band {band.name} to UTM with a {resolution} m resolution."
-        )
-
-        # Read band
-        with rasterio.open(str(path)) as src:
-            band_nb = self.band_names[band]
-            meta = src.meta.copy()
-
-            utm_tr, utm_w, utm_h = warp.calculate_default_transform(
-                src.crs,
-                self.crs(),
-                src.width,
-                src.height,
-                *src.bounds,
-                resolution=resolution,
-            )
-
-            # If nodata not set, set it here
-            meta["nodata"] = 0
-
-            # If the CRS is not in UTM, reproject it
-            out_arr = np.empty((1, utm_h, utm_w), dtype=meta["dtype"])
-            warp.reproject(
-                source=src.read(band_nb),
-                destination=out_arr,
-                src_crs=src.crs,
-                dst_crs=self.crs(),
-                src_transform=src.transform,
-                dst_transform=utm_tr,
-                src_nodata=0,
-                dst_nodata=0,  # input data should be in integer
-                num_threads=MAX_CORES,
-            )
-            meta["transform"] = utm_tr
-            meta["crs"] = self.crs()
-            meta["driver"] = "GTiff"
-
-            rasters_rio.write(out_arr, meta, reproj_path)
-
-    def _get_default_utm_band(
-        self, resolution: float = None, size: Union[list, tuple] = None
-    ) -> Union[CloudPath, Path]:
-        """
-        Get the default UTM band:
-        - If one already exists, get it
-        - If not, create reproject (if needed) the GREEN band
-
-        Args:
-            resolution (int): Band resolution in meters
-            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
-
-        Returns:
-            str: Default UTM path
-        """
-        # Manage resolution
-        if resolution is None and size is not None:
-            resolution = self._resolution_from_size(size)
-        def_res = resolution if resolution else self.resolution
-
-        # Get default band path
-        default_band = self.get_default_band()
-        def_path = self.get_band_paths([default_band], resolution=def_res)[default_band]
-
-        with rasterio.open(str(def_path)) as dst:
-            # First look for reprojected bands
-            reproj_regex = self._create_utm_band_path(band="*", resolution=resolution)
-
-            reproj_bands = glob.glob(str(reproj_regex))
-
-            if len(reproj_bands) == 0:
-                # Manage the case if we got a LAT LON product
-                dst_crs = dst.crs
-                if not dst_crs.is_projected:
-                    def_band = self.get_default_band()
-                    path = self._create_utm_band_path(
-                        band=def_band.name, resolution=resolution
-                    )
-
-                    # Warp band if needed
-                    if not path.is_file():
-                        self._warp_band(
-                            def_path,
-                            def_band,
-                            reproj_path=path,
-                            resolution=resolution,
-                        )
-                else:
-                    path = def_path
-            else:
-                path = AnyPath(reproj_bands[0])
-
-        return path
-
-    def default_transform(self) -> (affine.Affine, int, int, CRS):
-        """
-        Returns default transform data of the default band (UTM),
-        as the `rasterio.warp.calculate_default_transform` does:
-        - transform
-        - width
-        - height
-        - CRS
-
-        Overload in order not to reproject WGS84 data
-
-        Returns:
-            Affine, int, int: transform, width, height
-
-        """
-        default_band = self.get_default_band()
-        def_path = self.get_band_paths([default_band], resolution=self.resolution)[
-            default_band
-        ]
-        with rasterio.open(str(def_path)) as dst:
-            return dst.transform, dst.width, dst.height, dst.crs
