@@ -32,6 +32,7 @@ from sertit import vectors
 from sertit.misc import ListEnum
 from sertit.vectors import WGS84
 
+from eoreader import cache, cached_property
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
 from eoreader.products.sar.sar_product import SarProduct, SarProductType
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
@@ -186,10 +187,10 @@ class Rs2Product(SarProduct):
 
         return def_res
 
-    def _post_init(self) -> None:
+    def _pre_init(self) -> None:
         """
-        Function used to post_init the products
-        (setting product-type, band names and so on)
+        Function used to pre_init the products
+        (setting needs_extraction and so on)
         """
         # Private attributes
         self._raw_band_regex = "*imagery_{}.tif"
@@ -199,9 +200,19 @@ class Rs2Product(SarProduct):
         # Zipped and SNAP can process its archive
         self.needs_extraction = False
 
+        # Post init done by the super class
+        super()._pre_init()
+
+    def _post_init(self) -> None:
+        """
+        Function used to post_init the products
+        (setting product-type, band names and so on)
+        """
+
         # Post init done by the super class
         super()._post_init()
 
+    @cached_property
     def wgs84_extent(self) -> gpd.GeoDataFrame:
         """
         Get the WGS84 extent of the file before any reprojection.
@@ -212,7 +223,7 @@ class Rs2Product(SarProduct):
             >>> from eoreader.reader import Reader
             >>> path = r"RS2_OK73950_PK661843_DK590667_U25W2_20160228_112418_HH_SGF.zip"
             >>> prod = Reader().open(path)
-            >>> prod.wgs84_extent()
+            >>> prod.wgs84_extent
                                                         geometry
             1  POLYGON ((106.57999 -6.47363, 107.06926 -6.473...
 
@@ -254,7 +265,7 @@ class Rs2Product(SarProduct):
 
         if self.product_type == Rs2ProductType.SGF:
             self.sar_prod_type = SarProductType.GDRG
-        elif self.product_type in Rs2ProductType.SLC:
+        elif self.product_type == Rs2ProductType.SLC:
             self.sar_prod_type = SarProductType.CPLX
         else:
             raise NotImplementedError(
@@ -312,24 +323,28 @@ class Rs2Product(SarProduct):
         Returns:
              Union[str, datetime.datetime]: Its acquisition datetime
         """
-        # Get MTD XML file
-        root, nsmap = self.read_mtd()
-        namespace = nsmap[None]
+        if self.datetime is None:
+            # Get MTD XML file
+            root, nsmap = self.read_mtd()
+            namespace = nsmap[None]
 
-        # Open identifier
-        try:
-            acq_date = root.findtext(f".//{namespace}rawDataStartTime")
-        except TypeError:
-            raise InvalidProductError("rawDataStartTime not found in metadata !")
+            # Open identifier
+            try:
+                acq_date = root.findtext(f".//{namespace}rawDataStartTime")
+            except TypeError:
+                raise InvalidProductError("rawDataStartTime not found in metadata !")
 
-        # Convert to datetime
-        date = datetime.strptime(acq_date, "%Y-%m-%dT%H:%M:%S.%fZ")
+            # Convert to datetime
+            date = datetime.strptime(acq_date, "%Y-%m-%dT%H:%M:%S.%fZ")
+        else:
+            date = self.datetime
 
         if not as_datetime:
             date = date.strftime(DATETIME_FMT)
 
         return date
 
+    @cache
     def _read_mtd(self) -> (etree._Element, dict):
         """
         Read metadata and outputs the metadata XML root and its namespaces as a dict
