@@ -31,6 +31,7 @@ from lxml import etree
 from sertit import vectors
 from sertit.misc import ListEnum
 
+from eoreader import cache, cached_property
 from eoreader.exceptions import InvalidProductError
 from eoreader.products.sar.sar_product import SarProduct, SarProductType
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
@@ -97,36 +98,44 @@ class S1Product(SarProduct):
 
         .. WARNING:: We assume being in High Resolution (except for WV where we must be in medium resolution)
         """
-        def_res = None
+        root, _ = self.read_mtd()
 
         # Read metadata
         try:
-            root, _ = self.read_mtd()
             def_res = float(root.findtext(".//rangePixelSpacing"))
-        except (InvalidProductError, TypeError):
+        except TypeError:
             raise InvalidProductError(
                 "rangePixelSpacing or rowSpacing not found in metadata !"
             )
 
         return def_res
 
-    def _post_init(self) -> None:
+    def _pre_init(self) -> None:
         """
-        Function used to post_init the products
-        (setting product-type, band names and so on)
+        Function used to pre_init the products
+        (setting needs_extraction and so on)
         """
         # Private attributes
         self._raw_band_regex = "*-{!l}-*.tiff"  # Just get the SLC-iw1 image for now
-
         self._band_folder = self.path.joinpath("measurement")
         self._snap_path = ""
 
         # Zipped and SNAP can process its archive
         self.needs_extraction = False
 
+        # Post init done by the super class
+        super()._pre_init()
+
+    def _post_init(self) -> None:
+        """
+        Function used to post_init the products
+        (setting product-type, band names and so on)
+        """
+
         # Post init done by the super class
         super()._post_init()
 
+    @cached_property
     def wgs84_extent(self) -> gpd.GeoDataFrame:
         """
         Get the WGS84 extent of the file before any reprojection.
@@ -137,7 +146,7 @@ class S1Product(SarProduct):
             >>> from eoreader.reader import Reader
             >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
             >>> prod = Reader().open(path)
-            >>> prod.wgs84_extent()
+            >>> prod.wgs84_extent
                                    Name  ...                                           geometry
             0  Sentinel-1 Image Overlay  ...  POLYGON ((0.85336 42.24660, -2.32032 42.65493,...
             [1 rows x 12 columns]
@@ -249,23 +258,27 @@ class S1Product(SarProduct):
         Returns:
              Union[str, datetime.datetime]: Its acquisition datetime
         """
-        # Get MTD XML file
-        root, _ = self.read_mtd()
+        if self.datetime is None:
+            # Get MTD XML file
+            root, _ = self.read_mtd()
 
-        # Open identifier
-        try:
-            acq_date = root.findtext(".//startTime")
-        except TypeError:
-            raise InvalidProductError("startTime not found in metadata !")
+            # Open identifier
+            try:
+                acq_date = root.findtext(".//startTime")
+            except TypeError:
+                raise InvalidProductError("startTime not found in metadata !")
 
-        # Convert to datetime
-        date = datetime.strptime(acq_date, "%Y-%m-%dT%H:%M:%S.%f")
+            # Convert to datetime
+            date = datetime.strptime(acq_date, "%Y-%m-%dT%H:%M:%S.%f")
+        else:
+            date = self.datetime
 
         if not as_datetime:
             date = date.strftime(DATETIME_FMT)
 
         return date
 
+    @cache
     def _read_mtd(self) -> (etree._Element, dict):
         """
         Read metadata and outputs the metadata XML root and its namespaces as a dict
@@ -282,6 +295,8 @@ class S1Product(SarProduct):
             (etree._Element, dict): Metadata XML root and its namespaces
         """
         mtd_from_path = "annotation/*.xml"
-        mtd_archived = "annotation.*\.xml"
+
+        # When archived, other XML (in calibration folder) can be found
+        mtd_archived = "annotation/(?!cal)(?!noise).*\.xml"
 
         return self._read_mtd_xml(mtd_from_path, mtd_archived)
